@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.008_01';
+our $VERSION = '0.009_01';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -225,6 +225,23 @@ END
 #  ACTION methods  #
 ####################
 
+sub ACTION_alien_fakebuild {
+  my $self = shift;
+
+  print "# Build\n";
+  foreach my $cmd (@{ $self->alien_build_commands })
+  {
+    my @cmd = map { $self->alien_interpolate($_) } ref($cmd) ? @$cmd : ($cmd);
+    print "+ @cmd\n";
+  }
+  print "# Build install\n";
+  foreach my $cmd (@{ $self->alien_install_commands })
+  {
+    my @cmd = map { $self->alien_interpolate($_) } ref($cmd) ? @$cmd : ($cmd);
+    print "+ @cmd\n";
+  }
+}
+
 sub ACTION_code {
   my $self = shift;
   $self->notes( 'alien_blib_scheme' => $self->alien_detect_blib_scheme );
